/*
 * 
 * Copyright
 *  2009 axYus - www.axyus.com
 *  2009 Christophe Marchand <christophe.marchand@axyus.com>
 * 
 * This file is part of XEMELIOS.
 * 
 * XEMELIOS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * XEMELIOS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with XEMELIOS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

package fr.gouv.finances.dgfip.xemelios.batch.exports;

import fr.gouv.finances.dgfip.xemelios.batch.PostProcessor;
import fr.gouv.finances.cp.xemelios.export.ExportUndertaker;
import fr.gouv.finances.cp.xemelios.export.Exporter;
import fr.gouv.finances.dgfip.xemelios.auth.XemeliosUser;
import fr.gouv.finances.dgfip.xemelios.batch.Batch;
import fr.gouv.finances.dgfip.xemelios.batch.BatchRunner;
import fr.gouv.finances.dgfip.xemelios.common.Constants;
import fr.gouv.finances.dgfip.xemelios.common.config.DocumentModel;
import fr.gouv.finances.dgfip.xemelios.common.config.DocumentsModel;
import fr.gouv.finances.dgfip.xemelios.common.config.ElementModel;
import fr.gouv.finances.dgfip.xemelios.common.config.Loader;
import fr.gouv.finances.dgfip.xemelios.data.DataConfigurationException;
import fr.gouv.finances.dgfip.xemelios.data.DataLayerManager;
import fr.gouv.finances.dgfip.xemelios.data.DataResultSet;
import fr.gouv.finances.dgfip.xemelios.data.impl.pool.PoolManager;
import fr.gouv.finances.dgfip.xemelios.export.ConfigModel;
import fr.gouv.finances.dgfip.xemelios.export.ExportJob;
import fr.gouv.finances.dgfip.xemelios.utils.FileUtils;
import java.io.File;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import org.apache.log4j.Logger;

/**
 *
 * @author Christophe Marchand <christophe.marchand@axyus.com>
 */
public class ExportRunner extends Batch {
    private static final Logger logger = Logger.getLogger(ExportRunner.class);
    
    public static final String PROP_PRIORITY_LEVEL = "priority.level";
    public static final String PROP_MAX_CONCURRENT_THREADS = "max.concurrent.threads";
    public static final String PROP_DOCUMENTS_DEF_DIR = "documents-def.dir";
    public static final String PROP_DATALAYER_NAME = "datalayer.name";
    public static final String PROP_UNDERTAKER = "exporter.class.name";
//    public static final String PROP_POST_PROCESSOR = "post.processor.class.name";
    
    private int priorityLevel = 1;
    private int maxConcurrentThreads = 1;

    private String exportTempDirectory = null;
    private String undertakerClassName;
//    private String postProcessorClassName;

    private DocumentsModel docs;

    public ExportRunner(String args[]) {
        super(args);
    }

    @Override
    protected void initialize() throws Exception {
        super.initialize();
        String sTmp = getProps().getProperty(PROP_MAX_CONCURRENT_THREADS);
        if(sTmp!=null && sTmp.length()>0) {
            try {
                maxConcurrentThreads = Integer.parseInt(sTmp);
            } catch(Throwable t) {}
        }
        try {
            String s = getProps().getProperty(PROP_PRIORITY_LEVEL);
            if(s!=null && s.length()>0) {
                priorityLevel = Integer.parseInt(s);
            }
        } catch(Throwable t) {}
        String dirs = getProps().getProperty("documents-def.dir");
        File baseDir = BatchRunner.getBaseDir();
        String canon = baseDir.getCanonicalPath().replace("\\", "/");
        String documentsDefDirs = dirs.replaceAll("%basedir%", canon);
        undertakerClassName = getProps().getProperty(PROP_UNDERTAKER);
//        postProcessorClassName = getProps().getProperty(PROP_POST_PROCESSOR);
        docs = Loader.getDocumentsInfos(documentsDefDirs);
        initDataLayer();
    }


    @Override
    protected void doProcess() throws Exception {
        Connection con = null;
        Statement st = null;
        PreparedStatement ps = null;
        ResultSet rs = null;
        ArrayList<ExportRunnerImpl> threads = new ArrayList<ExportRunnerImpl>();
        try {
            con = PoolManager.getInstance().getConnection();
            String sqlParam = "SELECT PARAM_VALUE FROM PARAMETERS WHERE PARAM_NAME='export.temp.directory'";
            st = con.createStatement();
            rs = st.executeQuery(sqlParam);
            if(rs.next()) {
                exportTempDirectory = rs.getString(1);
                rs.close();
            } else {
                logger.error("parameter 'export.temp.directory' not set !");
                throw new Exception("parameter 'export.temp.directory' not set !");
            }
            String sql = "SELECT EXPORT_ID FROM EXPORT_JOBS WHERE STATUS=1 AND PRIORITY=? AND CLEANED IS NULL";
            ps = con.prepareStatement(sql);
            ps.setInt(1,priorityLevel);
            rs = ps.executeQuery();
            while(rs.next()) {
                threads.add(new ExportRunnerImpl(rs.getLong(1),priorityLevel,exportTempDirectory,docs,undertakerClassName,getPostProcessors()));
            }
            ThreadPool<ExportRunnerImpl> pool = new ThreadPool<ExportRunnerImpl>(threads);
            pool.start(maxConcurrentThreads);
        } catch(SQLException sqlEx) {
            logger.error("doProcess()",sqlEx);
        } finally {
            if(con!=null) PoolManager.getInstance().releaseConnection(con);
        }
    }

    @Override
    public String getResumeTraitement() {
        return "export.runner.resume";
    }

    @Override
    public String typeTraitementRefCode() {
        return "export.runner<"+priorityLevel+">";
    }
    protected void initDataLayer() throws DataConfigurationException {
        try {
            DataLayerManager.getImplementation();
        } catch(DataConfigurationException dcEx) {
            String availableLayers = System.getProperty(Constants.SYS_PROP_AVAILABLE_LAYERS,"fr.gouv.finances.cp.xemelios.data.impl.MySqlDataLayer");
            StringTokenizer tokenizer = new StringTokenizer(availableLayers, ",");
            while (tokenizer.hasMoreTokens()) {
                String className = tokenizer.nextToken();
                try {
                    Class.forName(className);
                } catch (ClassNotFoundException cnfEx) {
                    logger.error("instanciating data layer: ", cnfEx);
                }
            }
            DataLayerManager.setDataImpl(getProps().getProperty(PROP_DATALAYER_NAME,"mysql"));
        }
    }

    protected class ExportRunnerImpl extends RunnableBatch {
        private Long exportId;
        private int priority;
        private String exportDirectory;
        private DocumentsModel docs;
        private String undertakerClassName;
//        private String postProcessorClassName;
        private List<String> postProcessors;

        private ExportJob job = null;

        private File generatedFile;

        public ExportRunnerImpl(Long exportId, int priority, String exportDirectory, DocumentsModel docs, String undertakerClassName,List<String> postProcessors) {
            this.exportId=exportId;
            this.priority=priority;
            this.exportDirectory=exportDirectory;
            this.docs=docs;
            this.undertakerClassName=undertakerClassName;
            this.postProcessors=postProcessors;
//            this.postProcessorClassName=postProcessorClassName;
            setName("ExportRunnerImpl<"+exportId+">");

            switch(priority) {
                case 2: { setPriority(Thread.MIN_PRIORITY); break; }
                default: { setPriority(Thread.NORM_PRIORITY); break; }
            }
        }

        @Override
        public void run() {
            Connection con = null;
            File temp = null;
            try {
                job = DataLayerManager.getImplementation().getExportJob(exportId);
                con = PoolManager.getInstance().getConnection();
                String sql = "UPDATE EXPORT_JOBS SET STATUS="+ExportJob.STATUS_RUNNING+", RUN_DATE=NOW() WHERE EXPORT_ID=?";
                PreparedStatement ps = con.prepareStatement(sql);
                ps.setLong(1, exportId);
                ps.executeUpdate();
                DataResultSet drs = job.getDataResultSet();
                File dir = new File(exportDirectory);
                temp = File.createTempFile("exp-", null, dir);
                temp.delete();
                temp.mkdir();
                String fileName = null;
                if(job.getFileName().toLowerCase().endsWith(".xls")) fileName = job.getFileName();
                else fileName = job.getFileName().concat(".xls");
                generatedFile = new File(temp,fileName);
                DocumentModel dm = docs.getDocumentById(job.getDocumentId());
                User user = new User(job.getOwner());
                ConfigModel cm = DataLayerManager.getImplementation().getConfigExport(job.getDocumentId(), job.getEtatId(), job.getExportConfigId().toString(), user);
                Exporter exporter = new MyExporter(generatedFile, drs, dm, job.getEtatId(), dm.getEtatById(job.getEtatId()).getElementById(job.getElementId()), cm, this, undertakerClassName);
                exporter.execute();
            } catch(Exception ex) {
                logger.error("run()",ex);
                try {
                    String sql = "UPDATE EXPORT_JOBS SET STATUS="+ExportJob.STATUS_ERROR+", ERROR_MESSAGE=? WHERE EXPORT_ID=?";
                    PreparedStatement ps = con.prepareStatement(sql);
                    ps.setLong(1, exportId);
                    ps.setString(2,ex.getMessage());
                    ps.executeUpdate();
                } catch(SQLException sqlEx) {}
                if(temp!=null) {
                    if(temp.exists()) {
                        if(temp.isDirectory()) {
                            try {
                                FileUtils.dropRecursiveDirectory(temp);
                            } catch(Exception ex2) {}
                        } else {
                            temp.delete();
                        }
                    }
                }
            } finally {
                if(con!=null) PoolManager.getInstance().releaseConnection(con);
                // c'est fait par le MyExporter
                // getNotifier().notifyThreadStop(this);
            }
        }
        public void notifyTerminated() {
            Connection con = null;
            try {
                con = PoolManager.getInstance().getConnection();
                PreparedStatement ps = con.prepareStatement("UPDATE EXPORT_JOBS SET GENERATED_FILE_NAME=? WHERE EXPORT_ID=?");
                ps.setString(1, generatedFile.getAbsolutePath());
                ps.setLong(2, exportId);
                ps.executeUpdate();
                job.setGeneratedFileName(generatedFile.getAbsolutePath());

                // post processors
                for(String postProcessor:postProcessors) {
                    PostProcessor pp = null;
                    try {
                        Class clazz = Class.forName(postProcessor);
                        Object o = clazz.newInstance();
                        pp = (PostProcessor)o;
                    } catch(Exception ex) {
                        logger.error("instanciating post processor",ex);
                    }
                    if(pp!=null) {
                        pp.setConfigData(job);
                        pp.postProcess();
                    }
                }

                ps=con.prepareStatement("UPDATE EXPORT_JOBS SET STATUS="+ExportJob.STATUS_TERMINATED+" WHERE EXPORT_ID=?");
                ps.setLong(1, exportId);
                ps.executeUpdate();

            } catch(Exception ex) {
                logger.error("notifyTerminated()",ex);
                try {
                    String sql = "UPDATE EXPORT_JOBS SET STATUS="+ExportJob.STATUS_ERROR+", ERROR_MESSAGE=? WHERE EXPORT_ID=?";
                    PreparedStatement ps = con.prepareStatement(sql);
                    ps.setLong(1, exportId);
                    ps.setString(2,ex.getMessage());
                    ps.executeUpdate();
                } catch(SQLException sqlEx) {}
                // cleanning
                File generated = new File(job.getGeneratedFileName());
                if(generated.exists()) {
                    try {
                        FileUtils.dropRecursiveDirectory(generated.getParentFile());
                    } catch(Throwable t) {}
                }
            } finally {
                if(con!=null) PoolManager.getInstance().releaseConnection(con);
            }
            getNotifier().notifyThreadStop(this);
        }
    }

    private class User implements XemeliosUser {
        private String userId;
        public User(String userId) {
            super();
            this.userId = userId;
        }
        public String getId() {
            return userId;
        }
        public String getDisplayName() {
            return userId;
        }
        public boolean hasRole(String role) {
            return true;
        }
        public boolean hasDocument(String document) {
            return true;
        }
        public boolean hasCollectivite(String collectivite, DocumentModel dm) {
            return true;
        }
    }

    private class MyExporter extends Exporter {
        private ExportRunnerImpl impl;
        private String undertakerClassName;

        public MyExporter(File f, DataResultSet drs, DocumentModel dm, String etatId, ElementModel em, ConfigModel cf, ExportRunnerImpl notifier, String undertakerClassName) {
            super(f,drs,dm,etatId,em,cf);
            this.undertakerClassName=undertakerClassName;
            if(this.undertakerClassName==null || this.undertakerClassName.length()==0) {
                this.undertakerClassName = "fr.gouv.finances.cp.xemelios.export.JxlExporter";
            }
            this.impl=notifier;
        }

        @Override
        protected void done() {
            super.done();
            impl.notifyTerminated();
        }

        @Override
        protected ExportUndertaker getUndertaker() {
            try {
                Class undertakerClass = Class.forName(undertakerClassName);
                Class[] exporterArgsClass = new Class[]{Exporter.class};
                Object[] exporterArgs = new Object[]{this};
                Constructor constructor = undertakerClass.getConstructor(exporterArgsClass);
                ExportUndertaker undertaker = (ExportUndertaker) constructor.newInstance(exporterArgs);
    //            System.out.println("Builr undertaker of class " + undertakerClassName);

                return undertaker;
            } catch (ClassNotFoundException e) {
                logger.error("",e);
                return null;
            } catch (NoSuchMethodException e) {
                logger.error("",e);
                return null;
            } catch (InstantiationException e) {
                logger.error("",e);
                return null;
            } catch (IllegalAccessException e) {
                logger.error("",e);
                return null;
            } catch (IllegalArgumentException e) {
                logger.error("",e);
                return null;
            } catch (InvocationTargetException e) {
                logger.error("",e);
                return null;
            }
        }

    }
}
