/*
 * Copyright 
 *   2005 axYus - www.axyus.com
 *   2005 L.Meckert - lmeckert@club-internet.fr
 * 
 * This file is part of XEMELIOS.
 * 
 * XEMELIOS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * XEMELIOS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with XEMELIOS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package fr.gouv.finances.cp.xemelios.patches;

import fr.gouv.finances.dgfip.xemelios.data.DataImpl;
import fr.gouv.finances.dgfip.xemelios.data.DataLayerManager;
import fr.gouv.finances.dgfip.xemelios.export.ConfigModel;
import fr.gouv.finances.dgfip.xemelios.export.ConfigParser;
import fr.gouv.finances.cp.xemelios.updater.AbstractConfigurator;
import fr.gouv.finances.dgfip.xemelios.auth.XemeliosUser;
import fr.gouv.finances.dgfip.xemelios.common.config.DocumentModel;
import java.io.ByteArrayInputStream;
import java.util.Vector;

/**
 *
 * @author chm
 */
public class Core33114 extends AbstractConfigurator {
    private static final String CFG_PAYE_BULLETIN = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"documentPaye\" etatID=\"etatPaye\" owner=\"Xemelios\" code=\"Bulletin - Tous champs\" libelle=\"Bulletin (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJC\n" +
"dWxsZXRpbiAtIFRvdXMgY2hhbXBzIiBsaWJlbGxlPSJCdWxsZXRpbiAoY29uZmlnLiBwYXIgZOlm\n" +
"YXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJwYXllSW5kaXZNZW5zdWVsIiBsaWJlbGxlPSJC\n" +
"dWxsZXRpbnMgZGUgcGF5ZSI+CiAgPGNoYW1wIGlkPSJscjEiIGxpYmVsbGU9IkFubullIiBlZGl0\n" +
"YWJsZT0iZmFsc2UiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPgogIDxj\n" +
"aGFtcCBpZD0ibHIyIiBsaWJlbGxlPSJNb2lzIiBlZGl0YWJsZT0iZmFsc2UiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPgogIDxjaGFtcCBpZD0ibHIzIiBsaWJlbGxlPSJO\n" +
"b20iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgPGNoYW1wIGlkPSJscjQiIGxpYmVsbGU9IlBy6W5vbSIgZWRpdGFibGU9InRydWUiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMTUi\n" +
"IGxpYmVsbGU9Ik1hdHJpY3VsZSIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIg\n" +
"aWRlbnRpZmlhbnQ9InRydWUiLz4KICA8Y2hhbXAgaWQ9ImxyNSIgbGliZWxsZT0iU3RhdHV0IiBl\n" +
"ZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgog\n" +
"IDxjaGFtcCBpZD0ibHI2IiBsaWJlbGxlPSJFbXBsb2kiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rp\n" +
"b25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjciIGxpYmVs\n" +
"bGU9IlNlcnZpY2UiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlh\n" +
"bnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjgiIGxpYmVsbGU9IkluZGljZSIgZWRpdGFibGU9\n" +
"InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAg\n" +
"aWQ9ImxyOSIgbGliZWxsZT0iTmV0IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxMCIgbGliZWxsZT0iQnJ1dCIg\n" +
"ZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImxyMjYiIGxpYmVsbGU9IkltcG9zLiIgZWRpdGFibGU9InRydWUiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMjUiIGxp\n" +
"YmVsbGU9IkhldXJlcyBTdXAuIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIyNCIgbGliZWxsZT0iSGV1cmVzIiBl\n" +
"ZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgog\n" +
"IDxjaGFtcCBpZD0ibHIyMyIgbGliZWxsZT0iVGVtcHMgZGUgdHJhdmFpbCIgZWRpdGFibGU9InRy\n" +
"dWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9\n" +
"ImxyMTYiIGxpYmVsbGU9Ik5pciIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBp\n" +
"ZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9Im5iZW5mIiBsaWJlbGxlPSJFbmZhbnRz\n" +
"IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIv\n" +
"PgogIDxjaGFtcCBpZD0ibHIxOSIgbGliZWxsZT0iR3JhZGUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxl\n" +
"Y3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjIwIiBs\n" +
"aWJlbGxlPSJFY2hlbG9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50\n" +
"aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxNjEiIGxpYmVsbGU9Ik5vbWVuY2wuIFN0\n" +
"YXR1dGFpcmUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9\n" +
"ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjE3IiBsaWJlbGxlPSJSSUIiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJl\n" +
"dGFibCIgbGliZWxsZT0iRXRhYmxpc3NlbWVudCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8ZWxlbWVudCBpZD0iUmVwYXJ0aXRpb25C\n" +
"dWRnZXQiIGxpYmVsbGU9IlLpcGFydGl0aW9uIEJ1ZGfpdGFpcmUiPgogICA8Y2hhbXAgaWQ9ImU0\n" +
"QzEiIGxpYmVsbGU9IkNvZGUgQnVkZ2V0IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImU0QzIiIGxpYmVsbGU9IlRh\n" +
"dXgiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+PC9lbGVtZW50PgogIDxlbGVtZW50IGlkPSJldnQiIGxpYmVsbGU9IkV26G5lbWVudHMgZGUg\n" +
"cGF5ZSI+CiAgIDxjaGFtcCBpZD0iQzEiIGxpYmVsbGU9IkNvZGUiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0iQzIi\n" +
"IGxpYmVsbGU9IkRlc2NyaXB0aW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPjwvZWxlbWVudD4KICA8ZWxlbWVudCBpZD0ibGlnbmVQYXll\n" +
"IiBsaWJlbGxlPSJMaWduZXMgZGUgcGF5ZSI+CiAgIDxjaGFtcCBpZD0iZTJscjEiIGxpYmVsbGU9\n" +
"IkFubullIiBlZGl0YWJsZT0iZmFsc2UiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"dHJ1ZSIvPgogICA8Y2hhbXAgaWQ9ImUybHIyIiBsaWJlbGxlPSJNb2lzIiBlZGl0YWJsZT0iZmFs\n" +
"c2UiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPgogICA8Y2hhbXAgaWQ9\n" +
"ImUybHI1IiBsaWJlbGxlPSJNYXRyaWN1bGUiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJ0cnVlIi8+CiAgIDxjaGFtcCBpZD0iZTJscjYiIGxpYmVsbGU9\n" +
"IkxpYmVsbOkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9\n" +
"ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0iZTJscjciIGxpYmVsbGU9IkNvZGUiIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBp\n" +
"ZD0ibHJCYXNlIiBsaWJlbGxlPSJCYXNlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImUybHI4IiBsaWJlbGxlPSJU\n" +
"YXV4IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxz\n" +
"ZSIvPgogICA8Y2hhbXAgaWQ9ImUybHI5IiBsaWJlbGxlPSJOYi4gVW5pdOkiIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBp\n" +
"ZD0ibHJDYWlzc2UiIGxpYmVsbGU9IkNvZGUgY2Fpc3NlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0\n" +
"aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImUybHIxMCIg\n" +
"bGliZWxsZT0iTW9udGFudCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVu\n" +
"dGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJlMmxyMTEiIGxpYmVsbGU9IkRhdGUgZOli\n" +
"dXQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgIDxjaGFtcCBpZD0iZTJscjEyIiBsaWJlbGxlPSJEYXRlIGZpbiIgZWRpdGFibGU9InRy\n" +
"dWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz48L2VsZW1lbnQ+CiAg\n" +
"PGVsZW1lbnQgaWQ9IlBKUmVmIiBsaWJlbGxlPSJQaehjZXMganVzdGZpY2F0aXZlcyI+CiAgIDxj\n" +
"aGFtcCBpZD0iZTVDMSIgbGliZWxsZT0iU3VwcG9ydCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJlNUMyIiBsaWJl\n" +
"bGxlPSJJZFVuaXF1ZSIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9InRydWUiLz4KICAgPGNoYW1wIGlkPSJlNUMzIiBsaWJlbGxlPSJOb20gUEoiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+PC9lbGVt\n" +
"ZW50PgogIDxlbGVtZW50IGlkPSJOQkkiIGxpYmVsbGU9Ik5CSSI+CiAgIDxjaGFtcCBpZD0iZTND\n" +
"MSIgbGliZWxsZT0iTkJJIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50\n" +
"aWZpYW50PSJmYWxzZSIvPjwvZWxlbWVudD4KIDwvZWxlbWVudD4KPC9leHBvcnQ+Cg==\n" +
"</ConfigModel>";
    
    public static final String CFG_PAYE_REPART_NAT = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"documentPaye\" etatID=\"RepartitionNature\" owner=\"Xemelios\" code=\"Rpart. Nat - Tous champs\" libelle=\"Rpart. Nature (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJS\n" +
"6XBhcnQuIE5hdHVyZSAtIFRvdXMgY2hhbXBzIiBsaWJlbGxlPSJS6XBhcnQuIE5hdHVyZSAoY29u\n" +
"ZmlnLiBwYXIgZOlmYXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJEZXRhaWxSZXBhcnRpdGlv\n" +
"bk5hdHVyZSIgbGliZWxsZT0iUulwYXJ0aXRpb24gcGFyIG5hdHVyZSI+CiAgPGNoYW1wIGlkPSJl\n" +
"NWxyMSIgbGliZWxsZT0iQW5u6WUiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJ0cnVlIi8+CiAgPGNoYW1wIGlkPSJlNWxyMiIgbGliZWxsZT0iTW9pcyIg\n" +
"ZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImU1bHIzIiBsaWJlbGxlPSJMaWJlbGzpIiBlZGl0YWJsZT0idHJ1ZSIgc2Vs\n" +
"ZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iZTVscjQi\n" +
"IGxpYmVsbGU9IkNvZGUiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50\n" +
"aWZpYW50PSJ0cnVlIi8+CiAgPGNoYW1wIGlkPSJlNWxyNSIgbGliZWxsZT0iTW9udGFudCIgZWRp\n" +
"dGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8\n" +
"Y2hhbXAgaWQ9ImU1bHI2IiBsaWJlbGxlPSJDb2RlIEJ1ZGdldCIgZWRpdGFibGU9ImZhbHNlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICA8Y2hhbXAgaWQ9ImU1bHI3\n" +
"IiBsaWJlbGxlPSJDb2RlIEZvbmN0aW9uIiBlZGl0YWJsZT0iZmFsc2UiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPjwvZWxlbWVudD4KPC9leHBvcnQ+Cg==\n" +
"</ConfigModel>";
    
    private static final String CFG_VERSEMENT_VERS = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"etatVersement\" etatID=\"etatVersement\" owner=\"Xemelios\" code=\"Versement - Tous champs\" libelle=\"Versement (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJW\n" +
"ZXJzZW1lbnQgLSBUb3VzIGNoYW1wcyIgbGliZWxsZT0iVmVyc2VtZW50IChjb25maWcuIHBhciBk\n" +
"6WZhdXQpIiBjb2RlPSIiPgogPGVsZW1lbnQgaWQ9InZlcnNlbWVudCIgbGliZWxsZT0iRG9ubull\n" +
"cyBkZSB2ZXJzZW1lbnQgcGFyIGLpbulmaWNpYWlyZSI+CiAgPGNoYW1wIGlkPSJscjEiIGxpYmVs\n" +
"bGU9IkFubullIiBlZGl0YWJsZT0iZmFsc2UiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFu\n" +
"dD0idHJ1ZSIvPgogIDxjaGFtcCBpZD0ibHJTZXF1ZW5jZSIgbGliZWxsZT0iTnVt6XJvIGQnb3Jk\n" +
"cmUiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJ0cnVl\n" +
"Ii8+CiAgPGNoYW1wIGlkPSJsckNvZGVQcmVzdGF0aW9uIiBsaWJlbGxlPSJQcmVzdGF0aW9uIiBl\n" +
"ZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgog\n" +
"IDxjaGFtcCBpZD0ibHJDb2RlUHJlc3RhdGlvblByaW5jaXBhbGUiIGxpYmVsbGU9IlByZXN0YXRp\n" +
"b24gUHJpbmNpcGFsZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlm\n" +
"aWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyNCIgbGliZWxsZT0iRGVzdGluYXRhaXJlIE5v\n" +
"bSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2Ui\n" +
"Lz4KICA8Y2hhbXAgaWQ9ImxyNSIgbGliZWxsZT0iRGVzdGluYXRhaXJlIFBy6W5vbSIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hh\n" +
"bXAgaWQ9ImxyMTIiIGxpYmVsbGU9Ik1vbnRhbnQgVmVyc2VtZW50IiBlZGl0YWJsZT0idHJ1ZSIg\n" +
"c2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHI2\n" +
"IiBsaWJlbGxlPSJEYXRlIFZlcnNlbWVudCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyNyIgbGliZWxsZT0iTmF0\n" +
"dXJlIERlY2lzaW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJCZW5lZk5haXNzIiBsaWJlbGxlPSJC6W7pZmlj\n" +
"aWFpcmUgKG5haXNzYW5jZSkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRl\n" +
"bnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjE3IiBsaWJlbGxlPSJSSUIiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJsckRlY2lzaW9uSWQiIGxpYmVsbGU9IkTpY2lzaW9uIChpZC4pIiBlZGl0YWJsZT0i\n" +
"dHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBp\n" +
"ZD0ibHJJZERlc3QiIGxpYmVsbGU9IkRlc3RpbmF0YWlyZSAoaWQpIiBlZGl0YWJsZT0idHJ1ZSIg\n" +
"c2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJU\n" +
"eXBlRGVzdCIgbGliZWxsZT0iRGVzdGluYXRhaXJlICh0eXBlKSIgZWRpdGFibGU9InRydWUiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyQ2F0\n" +
"RGVzdCIgbGliZWxsZT0iRGVzdGluYXRhaXJlIChjYXQuKSIgZWRpdGFibGU9InRydWUiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyRGVzdENQ\n" +
"IiBsaWJlbGxlPSJEZXN0aW5hdGFpcmUgKENQKSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyRGVzdFZpbGxlIiBs\n" +
"aWJlbGxlPSJEZXN0aW5hdGFpcmUgKHZpbGxlKSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyQmVuZWZJZCIgbGli\n" +
"ZWxsZT0iQulu6WZpY2lhcmUgKGlkKSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVl\n" +
"IiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyQmVuZWZUeXBlIiBsaWJlbGxl\n" +
"PSJC6W7pZmljaWFpcmUgKHR5cGUpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJCZW5lZkNhdCIgbGliZWxsZT0i\n" +
"Qulu6WZpY2lhaXJlIChjYXQuKSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBp\n" +
"ZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyQmVuZWZDUCIgbGliZWxsZT0iQulu\n" +
"6WZpY2lhaXJlIChDUCkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJsckJlbmVmVmlsbGUiIGxpYmVsbGU9IkLpbulm\n" +
"aWNpYWlyZSAoVmlsbGUpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50\n" +
"aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJCZW5lZkZhbWlsbGUiIGxpYmVsbGU9IkLp\n" +
"bulmaWNpYWlyZSAoZmFtaWxsZSkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIg\n" +
"aWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscklkVmVyc3QiIGxpYmVsbGU9IlZl\n" +
"cnNlbWVudCAoSWQpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJEZWNpc2lvbk5hdCIgbGliZWxsZT0iROljaXNp\n" +
"b24gKG5hdHVyZSkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlh\n" +
"bnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscklkRG9zc2llciIgbGliZWxsZT0iRG9zc2llciIg\n" +
"ZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImxyRGVjaXNpb25EYXRlRWZmZXQiIGxpYmVsbGU9IkTpY2lzaW9uIChkYXRl\n" +
"IGVmZmV0KSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyRGVjaXNpb25EYXRlRmluIiBsaWJlbGxlPSJE6WNpc2lv\n" +
"biAoZGF0ZSBmaW4pIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJTZXJ2aWNlIiBsaWJlbGxlPSJTZXJ2aWNlIiBl\n" +
"ZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgog\n" +
"IDxjaGFtcCBpZD0ibHJOdW1NYW5kYXQiIGxpYmVsbGU9Ik1hbmRhdCAobnVtKSIgZWRpdGFibGU9\n" +
"InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAg\n" +
"aWQ9ImxyQ29kZU5hdHVyZSIgbGliZWxsZT0iQ29kZSBOYXR1cmUiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJsckNv\n" +
"ZGVCdWRnZXQiIGxpYmVsbGU9IkNvZGUgQnVkZ2V0IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9u\n" +
"bmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHJDb2RlRm9uY3Rp\n" +
"b24iIGxpYmVsbGU9IkNvZGUgRm9uY3Rpb24iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJtb2lzIiBsaWJlbGxlPSJN\n" +
"b2lzIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxz\n" +
"ZSIvPjwvZWxlbWVudD4KPC9leHBvcnQ+Cg==\n" +
"</ConfigModel>";
    
    private static final String CFG_VERSEMENT_REPART = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"etatVersement\" etatID=\"RepartitionNature\" owner=\"Xemelios\" code=\"Rpart. Nat - Tous champs\" libelle=\"Rpart. Nature (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJS\n" +
"6XBhcnQuIE5hdHVyZSAtIFRvdXMgY2hhbXBzIiBsaWJlbGxlPSJS6XBhcnQuIE5hdHVyZSAoY29u\n" +
"ZmlnLiBwYXIgZOlmYXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJEZXRhaWxSZXBhcnRpdGlv\n" +
"bk5hdHVyZSIgbGliZWxsZT0iUulwYXJ0aXRpb25zIHBhciBuYXR1cmUiPgogIDxjaGFtcCBpZD0i\n" +
"bHJ4MSIgbGliZWxsZT0iQW5u6WUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIg\n" +
"aWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscngyIiBsaWJlbGxlPSJMaWJlbGzp\n" +
"IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIv\n" +
"PgogIDxjaGFtcCBpZD0ibHJ4MyIgbGliZWxsZT0iQ29kZSIgZWRpdGFibGU9InRydWUiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyeDQiIGxp\n" +
"YmVsbGU9Ik1vbnRhbnQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscng1IiBsaWJlbGxlPSJDb2RlIEJ1ZGdldCIg\n" +
"ZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImxyeDYiIGxpYmVsbGU9IkNvZGUgRm9uY3Rpb24iIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+PC9lbGVtZW50Pgo8L2V4\n" +
"cG9ydD4K\n" +
"</ConfigModel>";
    
    private static final String CFG_FACTURE_DEP = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"DOC_FactureDepense\" etatID=\"PESFacture\" owner=\"Xemelios\" code=\"Facture Dp. Tous champs\" libelle=\"Facture Dp. (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJG\n" +
"YWN0dXJlIETpcC4gVG91cyBjaGFtcHMiIGxpYmVsbGU9IkZhY3R1cmUgROlwLiAoY29uZmlnLiBw\n" +
"YXIgZOlmYXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJGYWN0dXJlSW5kaXYiIGxpYmVsbGU9\n" +
"IkZhY3R1cmUgZGUgZOlwZW5zZSI+CiAgPGNoYW1wIGlkPSJscjEiIGxpYmVsbGU9IkRhdGUgZCfp\n" +
"bWlzc2lvbiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMTEiIGxpYmVsbGU9IklEIEVtZXR0ZXVyIiBlZGl0YWJs\n" +
"ZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFt\n" +
"cCBpZD0ibHIxMiIgbGliZWxsZT0iTm9tIEVtZXR0ZXVyIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0\n" +
"aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxMyIgbGli\n" +
"ZWxsZT0iUHLpbm9tIEVtZXR0ZXVyIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxNCIgbGliZWxsZT0iQWRyZXNz\n" +
"ZSBFbWV0dGV1ciAtIGxvY2FsaXNhdGlvbiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMTUiIGxpYmVsbGU9IkFk\n" +
"cmVzc2UgRW1ldHRldXIgLSBwcmluY2lwYWxlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxNiIgbGliZWxsZT0i\n" +
"QWRyZXNzZSBFbWV0dGV1ciAtIGNvbXBs6W1lbnQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25u\n" +
"ZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjE3IiBsaWJlbGxl\n" +
"PSJDb2RlIHBvc3RhbCBFbWV0dGV1ciIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVl\n" +
"IiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMTgiIGxpYmVsbGU9IlZpbGxl\n" +
"IEVtZXR0ZXVyIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHI2IiBsaWJlbGxlPSJNb250YW50IEhUIiBlZGl0YWJs\n" +
"ZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFt\n" +
"cCBpZD0ibHI3IiBsaWJlbGxlPSJNb250YW50IFRWQSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyOCIgbGliZWxs\n" +
"ZT0iTW9udGFudCBUVEMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+PC9lbGVtZW50Pgo8L2V4cG9ydD4K\n" +
"</ConfigModel>";
    
    private static final String CFG_CARTE_ACHAT ="<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"PES_ReleveCarteAchat\" etatID=\"PES_CarteAchat\" owner=\"Xemelios\" code=\"Carte achat - Tous champs\" libelle=\"Carte achat (cofnig. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJD\n" +
"YXJ0ZSBhY2hhdCAtIFRvdXMgY2hhbXBzIiBsaWJlbGxlPSJDYXJ0ZSBhY2hhdCAoY29mbmlnLiBw\n" +
"YXIgZOlmYXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJQRVNGYWN0dXJlIiBsaWJlbGxlPSJS\n" +
"ZWxldukiPgogIDxjaGFtcCBpZD0ibHIxIiBsaWJlbGxlPSJE6XNpZ25hdGlvbiDpbWV0dGV1ciIg\n" +
"ZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImxyMiIgbGliZWxsZT0iRGF0ZSBkdSByZWxldukiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJs\n" +
"cjMiIGxpYmVsbGU9Ik1vbnRhbnQgdG90YWwgSFQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25u\n" +
"ZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjQiIGxpYmVsbGU9\n" +
"Ik1vbnRhbnQgdG90YWwgVFZBIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHI1IiBsaWJlbGxlPSJNb250YW50IHRv\n" +
"dGFsIFRUQyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyNiIgbGliZWxsZT0iTrAgbWFyY2jpIiBlZGl0YWJsZT0i\n" +
"dHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBp\n" +
"ZD0ibHI3IiBsaWJlbGxlPSJOsCBDYXJ0ZSIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICA8Y2hhbXAgaWQ9ImxyOCIgbGliZWxsZT0iRm91\n" +
"cm5pc3NldXIiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9\n" +
"ImZhbHNlIi8+CiAgPGVsZW1lbnQgaWQ9IkZhY3R1cmVJbmRpdiIgbGliZWxsZT0iRmFjdHVyZSI+\n" +
"CiAgIDxjaGFtcCBpZD0iZTFscjAiIGxpYmVsbGU9Ik51belybyBGYWN0dXJlIiBlZGl0YWJsZT0i\n" +
"ZmFsc2UiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPgogICA8Y2hhbXAg\n" +
"aWQ9ImUxbHIxIiBsaWJlbGxlPSJEYXRlIGQn6W1pc3Npb24iIGVkaXRhYmxlPSJ0cnVlIiBzZWxl\n" +
"Y3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0iZTFscjIi\n" +
"IGxpYmVsbGU9Ik5vbSBmb3Vybmlzc2V1ciIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJlMWxyMyIgbGliZWxsZT0i\n" +
"TrAgTWFyY2jpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImUxbHI1IiBsaWJlbGxlPSJMaWJlbGzpIHByb2R1aXQi\n" +
"IGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+\n" +
"CiAgIDxjaGFtcCBpZD0iZTFscjYiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0i\n" +
"ZTFscjciIGxpYmVsbGU9Ik1vbnRhbnQgVFZBIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImUxbHI4IiBsaWJlbGxl\n" +
"PSJNb250YW50IFRUQyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlm\n" +
"aWFudD0iZmFsc2UiLz4KICAgPGVsZW1lbnQgaWQ9IkxpZ25lRmFjdHVyZSIgbGliZWxsZT0iTGln\n" +
"bmVzIGRlIEZhY3R1cmVzIj4KICAgIDxjaGFtcCBpZD0ibHJEYXRlIiBsaWJlbGxlPSJEYXRlIiBl\n" +
"ZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgog\n" +
"ICAgPGNoYW1wIGlkPSJsckRhdGVEZWJ1dCIgbGliZWxsZT0iRGF0ZSBk6WJ1dCIgZWRpdGFibGU9\n" +
"InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFt\n" +
"cCBpZD0ibHJEYXRlRmluIiBsaWJlbGxlPSJEYXRlIGZpbiIgZWRpdGFibGU9InRydWUiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0ibHJDb2Rl\n" +
"UHJvZHVpdCIgbGliZWxsZT0iQ29kZSBwcm9kdWl0IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9u\n" +
"bmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJsckNvZGVOYXR1\n" +
"cmUiIGxpYmVsbGU9IkNvZGUgbmF0dXJlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJsckNvZGVGb25jdGlvbiIg\n" +
"bGliZWxsZT0iQ29kZSBmb25jdGlvbiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVl\n" +
"IiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0ibHJMaWJlbGxlIiBsaWJlbGxl\n" +
"PSJMaWJlbGzpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJsclVuaXRlIiBsaWJlbGxlPSJVbml06SIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxj\n" +
"aGFtcCBpZD0ibHJRdWFudGl0ZSIgbGliZWxsZT0iUXVhbnRpdOkiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hhbXAgaWQ9Imxy\n" +
"TXRVbml0IiBsaWJlbGxlPSJNdCB1bml0YWlyZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0ibHJNdEJhc2UiIGxp\n" +
"YmVsbGU9Ik10IEJhc2UiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hhbXAgaWQ9ImxyVGF1eCIgbGliZWxsZT0iVGF1eCIgZWRp\n" +
"dGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAg\n" +
"IDxjaGFtcCBpZD0ibHJNdFJlbWlzZSIgbGliZWxsZT0iTXQgcmVtaXNlIiBlZGl0YWJsZT0idHJ1\n" +
"ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlk\n" +
"PSJsclRhdXhSZW1pc2UiIGxpYmVsbGU9IlRhdXggcmVtaXNlIiBlZGl0YWJsZT0idHJ1ZSIgc2Vs\n" +
"ZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJsck10\n" +
"SFQiIGxpYmVsbGU9Ik10IEhUIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJsclRhdXhUVkEiIGxpYmVsbGU9IlRh\n" +
"dXggVFZBIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJm\n" +
"YWxzZSIvPgogICAgPGNoYW1wIGlkPSJsck10VFZBIiBsaWJlbGxlPSJNdCBUVkEiIGVkaXRhYmxl\n" +
"PSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hh\n" +
"bXAgaWQ9Imx0TXRUVEMiIGxpYmVsbGU9Ik10IFRUQyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz48L2VsZW1lbnQ+CiAgPC9lbGVtZW50Pgog\n" +
"PC9lbGVtZW50Pgo8L2V4cG9ydD4K\n" +
"</ConfigModel>";
    
    private static final String CFG_FACTURE_REC = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"DOC_FactureRecette\" etatID=\"PESFacture\" owner=\"Xemelios\" code=\"Facture Rec. - Tous champ\" libelle=\"Facture Rec. (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJG\n" +
"YWN0dXJlIFJlYy4gLSBUb3VzIGNoYW1wcyIgbGliZWxsZT0iRmFjdHVyZSBSZWMuIChjb25maWcu\n" +
"IHBhciBk6WZhdXQpIiBjb2RlPSIiPgogPGVsZW1lbnQgaWQ9IkZhY3R1cmVJbmRpdiIgbGliZWxs\n" +
"ZT0iRmFjdHVyZSBkZSByZWNldHRlIj4KICA8Y2hhbXAgaWQ9ImxyMSIgbGliZWxsZT0iRGF0ZSBk\n" +
"J+ltaXNzaW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxMSIgbGliZWxsZT0iSUQgROliaXRldXIiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJscjEyIiBsaWJlbGxlPSJOb20gROliaXRldXIiIGVkaXRhYmxlPSJ0cnVlIiBzZWxl\n" +
"Y3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjEzIiBs\n" +
"aWJlbGxlPSJQculub20gROliaXRldXIiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjE0IiBsaWJlbGxlPSJBZHJl\n" +
"c3NlIETpYml0ZXVyIC0gbG9jYWxpc2F0aW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxNSIgbGliZWxsZT0i\n" +
"QWRyZXNzZSBE6WJpdGV1ciAtIHByaW5jaXBhbGUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25u\n" +
"ZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjE2IiBsaWJlbGxl\n" +
"PSJBZHJlc3NlIETpYml0ZXVyIC0gY29tcGzpbWVudCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMTciIGxpYmVs\n" +
"bGU9IkNQIETpYml0ZXVyIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50\n" +
"aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxOCIgbGliZWxsZT0iVmlsbGUgROliaXRl\n" +
"dXIiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgPGNoYW1wIGlkPSJscjYiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJs\n" +
"cjciIGxpYmVsbGU9Ik1vbnRhbnQgVFZBIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHI4IiBsaWJlbGxlPSJNb250\n" +
"YW50IFRUQyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz48L2VsZW1lbnQ+CjwvZXhwb3J0Pgo=\n" +
"</ConfigModel>";
    
    private static final String CFG_QUITTANCEMENT = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"DOC_Quittancement\" etatID=\"PESFacture\" owner=\"Xemelios\" code=\"Quittance - Tous champs\" libelle=\"Quittance (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJR\n" +
"dWl0dGFuY2VtZW50IC0gVG91cyBjaGFtcHMiIGxpYmVsbGU9IlF1aXR0YW5jZW1lbnQgKGNvbmZp\n" +
"Zy4gcGFyIGTpZmF1dCkiIGNvZGU9IiI+CiA8ZWxlbWVudCBpZD0iRmFjdHVyZUluZGl2IiBsaWJl\n" +
"bGxlPSJRdWl0dGFuY2VzIj4KICA8Y2hhbXAgaWQ9ImxyTnVtRmFjdHVyZSIgbGliZWxsZT0iTnVt\n" +
"LiBRdWl0dGFuY2UiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJ0cnVlIi8+CiAgPGNoYW1wIGlkPSJscjEiIGxpYmVsbGU9IkRhdGUgZCfpbWlzc2lvbiIg\n" +
"ZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImxyMTAiIGxpYmVsbGU9IklEIExvZ2VtZW50IiBlZGl0YWJsZT0idHJ1ZSIg\n" +
"c2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIx\n" +
"MSIgbGliZWxsZT0iSUQgTG9jYXRhaXJlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHIxMiIgbGliZWxsZT0iTm9t\n" +
"IExvY2F0YWlyZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFu\n" +
"dD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxyMTMiIGxpYmVsbGU9IlBy6W5vbSBMb2NhdGFpcmUi\n" +
"IGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+\n" +
"CiAgPGNoYW1wIGlkPSJscjYiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJscjci\n" +
"IGxpYmVsbGU9Ik1vbnRhbnQgVFZBIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibHI4IiBsaWJlbGxlPSJNb250YW50\n" +
"IFRUQyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFs\n" +
"c2UiLz4KICA8Y2hhbXAgaWQ9ImxvZ0FkcjEiIGxpYmVsbGU9IkxvZ2VtZW50IChBZHIgbG9jYWwu\n" +
"KSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2Ui\n" +
"Lz4KICA8Y2hhbXAgaWQ9ImxvZ0FkcjIiIGxpYmVsbGU9IkxvZ2VtZW50IChBZHIgcHJpbmNpcC4p\n" +
"IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIv\n" +
"PgogIDxjaGFtcCBpZD0ibG9nQWRyMyIgbGliZWxsZT0iTG9nZW1lbnQgKEFkciBjb21wbC4pIiBl\n" +
"ZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgog\n" +
"IDxjaGFtcCBpZD0ibG9nQ1AiIGxpYmVsbGU9IkxvZ2VtZW50IChDUCkiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJs\n" +
"b2dWaWxsZSIgbGliZWxsZT0iTG9nZW1lbnQgKFZpbGxlKSIgZWRpdGFibGU9InRydWUiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxvZ1BheXMi\n" +
"IGxpYmVsbGU9IkxvZ2VtZW50IChQYXlzKSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImxvY0FkcjEiIGxpYmVsbGU9\n" +
"IkxvY2F0YWlyZSAoQWRyIGxvY2FsLikiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJsb2NBZHIyIiBsaWJlbGxlPSJM\n" +
"b2NhdGFpcmUgKEFkciBwcmluY2lwLikiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJsb2NBZHIzIiBsaWJlbGxlPSJM\n" +
"b2NhdGFpcmUgKEFkciBjb21wbC4pIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibG9jQ1AiIGxpYmVsbGU9IkxvY2F0\n" +
"YWlyZSAoQ1ApIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibG9jVmlsbGUiIGxpYmVsbGU9IkxvY2F0YWlyZSAoVmls\n" +
"bGUpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxz\n" +
"ZSIvPgogIDxjaGFtcCBpZD0ibG9jUGF5cyIgbGliZWxsZT0iTG9jYXRhaXJlIChQYXlzKSIgZWRp\n" +
"dGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8\n" +
"Y2hhbXAgaWQ9Im51bUNvbnRyYXQiIGxpYmVsbGU9Ik51bS4gQ29udHJhdCIgZWRpdGFibGU9InRy\n" +
"dWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8ZWxlbWVudCBp\n" +
"ZD0iTGlnbmVGYWN0dXJlIiBsaWJlbGxlPSJMaWduZXMgcXVpdHRhbmNlcyI+CiAgIDxjaGFtcCBp\n" +
"ZD0ibHJDb2RlUHJvZHVpdCIgbGliZWxsZT0iQ29kZSBQcm9kdWl0IiBlZGl0YWJsZT0idHJ1ZSIg\n" +
"c2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9Imxy\n" +
"UHJvZHVpdCIgbGliZWxsZT0iVHlwZSBsaWduZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJsckxpYmVsbGUiIGxp\n" +
"YmVsbGU9IkxpYmVsbOkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0ibHJDb2RlTmF0dXJlIiBsaWJlbGxlPSJDb2Rl\n" +
"IE5hdHVyZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJsckNvZGVGb25jdGlvbiIgbGliZWxsZT0iQ29kZSBGb25j\n" +
"dGlvbiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFs\n" +
"c2UiLz4KICAgPGNoYW1wIGlkPSJsclVuaXRlIiBsaWJlbGxlPSJVbml06SIgZWRpdGFibGU9InRy\n" +
"dWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlk\n" +
"PSJsclF1YW50aXRlIiBsaWJlbGxlPSJRdWFudGl06SIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJsck10VW5pdCIg\n" +
"bGliZWxsZT0iTW9udGFudCB1bml0YWlyZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJsck10QmFzZSIgbGliZWxs\n" +
"ZT0iTW9udGFudCBkZSBCYXNlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImxyVGF1eCIgbGliZWxsZT0iVGF1eCIg\n" +
"ZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4K\n" +
"ICAgPGNoYW1wIGlkPSJsck10UmVtaXNlIiBsaWJlbGxlPSJNb250YW50IHJlbWlzZSIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNo\n" +
"YW1wIGlkPSJsclR4UmVtaXNlIiBsaWJlbGxlPSJUYXV4IFJlbWlzZSIgZWRpdGFibGU9InRydWUi\n" +
"IHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJs\n" +
"ck10SFQiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0ibHJUeFR2YSIgbGliZWxs\n" +
"ZT0iVGF1eCBUVkEiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlh\n" +
"bnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0ibHJNdFR2YSIgbGliZWxsZT0iTW9udGFudCBUVkEi\n" +
"IGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+\n" +
"CiAgIDxjaGFtcCBpZD0ibHJNdFRUQyIgbGliZWxsZT0iTW9udGFudCBUVEMiIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+PC9lbGVtZW50Pgog\n" +
"PC9lbGVtZW50Pgo8L2V4cG9ydD4K\n" +
"</ConfigModel>";
    
    private static final String CFG_PES_DEP = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"PES_Aller\" etatID=\"PES_DepenseAller\" owner=\"Xemelios\" code=\"PES Dpense - Tous champs\" libelle=\"PES Dpense (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJQ\n" +
"RVMgROlwZW5zZSAtIFRvdXMgY2hhbXBzIiBsaWJlbGxlPSJQRVMgROlwZW5zZSAoY29uZmlnLiBw\n" +
"YXIgZOlmYXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJCb3JkZXJlYXVEZXBlbnNlIiBsaWJl\n" +
"bGxlPSJCb3JkZXJlYXV4Ij4KICA8Y2hhbXAgaWQ9ImUxbHIxIiBsaWJlbGxlPSJFeGVyY2ljZSIg\n" +
"ZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImUxbHIyIiBsaWJlbGxlPSJUeXBlIGRlIEJvcmRlcmVhdSIgZWRpdGFibGU9\n" +
"ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICA8Y2hhbXAg\n" +
"aWQ9ImUxbHIzIiBsaWJlbGxlPSJOdW3pcm8gQm9yZGVyZWF1IiBlZGl0YWJsZT0iZmFsc2UiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPgogIDxjaGFtcCBpZD0iZTFscjQi\n" +
"IGxpYmVsbGU9IkRhdGUgRW1pc3Npb24iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJlMWxyNSIgbGliZWxsZT0iTmJy\n" +
"ZSBNYW5kYXRzIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iZTFscjYiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJlMWxyNyIgbGliZWxsZT0iTW9udGFudCBUVEMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxl\n" +
"Y3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGVsZW1lbnQgaWQ9IlBpZWNl\n" +
"IiBsaWJlbGxlPSJNYW5kYXRzIj4KICAgPGNoYW1wIGlkPSJlMmxyMSIgbGliZWxsZT0iRXhlcmNp\n" +
"Y2UiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgIDxjaGFtcCBpZD0iZTJscjIiIGxpYmVsbGU9Ik9iamV0IGR1IE1hbmRhdCIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNo\n" +
"YW1wIGlkPSJlMmxyMyIgbGliZWxsZT0iTmF0dXJlIGR1IE1hbmRhdCIgZWRpdGFibGU9InRydWUi\n" +
"IHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGNoYW1wIGlkPSJl\n" +
"MmxyNCIgbGliZWxsZT0iTnVt6XJvIGRlIE1hbmRhdCIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rp\n" +
"b25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICAgPGNoYW1wIGlkPSJlMmxyNSIgbGli\n" +
"ZWxsZT0iVHlwZSBkZSBNYW5kYXQiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJ0cnVlIi8+CiAgIDxjaGFtcCBpZD0iZTJscjciIGxpYmVsbGU9IkRhdGUg\n" +
"ZOlidXQgZHUgREdQIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImUybHI4IiBsaWJlbGxlPSJEYXRlIGZpbiBkdSBE\n" +
"R1AiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgIDxjaGFtcCBpZD0iZTJscjkiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBp\n" +
"ZD0iZTJscjEwIiBsaWJlbGxlPSJNb250YW50IFRUQyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgPGVsZW1lbnQgaWQ9IkxpZ25lRGVQ\n" +
"aWVjZSIgbGliZWxsZT0iTGlnbmVzIERlIE1hbmRhdCI+CiAgICA8Y2hhbXAgaWQ9ImUzbHIwIiBs\n" +
"aWJlbGxlPSJOdW3pcm8gZGUgbGlnbmUiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJ0cnVlIi8+CiAgICA8Y2hhbXAgaWQ9ImUzbHIxIiBsaWJlbGxlPSJO\n" +
"b20gZHUgY3LpYW5jaWVyIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50\n" +
"aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJlM2xyMiIgbGliZWxsZT0iUHLpbm9tIGR1\n" +
"IGNy6WFuY2llciIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFu\n" +
"dD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0iZTNscjMiIGxpYmVsbGU9Ik5hdHVyZSBKdXJpZGlx\n" +
"dWUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgICA8Y2hhbXAgaWQ9ImUzbHI0IiBsaWJlbGxlPSJDYXQuIFRpZXJzIiBlZGl0YWJsZT0i\n" +
"dHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1w\n" +
"IGlkPSJlM2xyNSIgbGliZWxsZT0iRXhlcmNpY2UiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25u\n" +
"ZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hhbXAgaWQ9ImUzbHI2IiBsaWJl\n" +
"bGxlPSJPYmouIE1hbmRhdCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVu\n" +
"dGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0iZTNscjciIGxpYmVsbGU9Ik51belybyBk\n" +
"ZSBNYW5kYXQiIGVkaXRhYmxlPSJmYWxzZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJ0cnVlIi8+CiAgICA8Y2hhbXAgaWQ9ImUzbHI4IiBsaWJlbGxlPSJOdW3pcm8gZGUgbWFyY2jp\n" +
"IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIv\n" +
"PgogICAgPGNoYW1wIGlkPSJlM2xyOSIgbGliZWxsZT0iQ29tcHRlIFRpZXJzIiBlZGl0YWJsZT0i\n" +
"dHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1w\n" +
"IGlkPSJlM2xyMTAiIGxpYmVsbGU9IkltcHV0LiBOYXR1cmUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxl\n" +
"Y3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hhbXAgaWQ9ImUzbHIx\n" +
"MSIgbGliZWxsZT0iSW1wdXQuIEZvbmN0aW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJlM2xyMTIiIGxpYmVs\n" +
"bGU9IkNvZGUgT3DpcmF0aW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJlM2xyMTMiIGxpYmVsbGU9Ik10IEhU\n" +
"IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIv\n" +
"PgogICAgPGNoYW1wIGlkPSJlM2xyMTQiIGxpYmVsbGU9Ik10IFRUQyIgZWRpdGFibGU9InRydWUi\n" +
"IHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0i\n" +
"ZTNscjE1IiBsaWJlbGxlPSJJZGVudGlmaWFudCBuYXRpb25hbCIgZWRpdGFibGU9InRydWUiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz48L2VsZW1lbnQ+CiAgPC9lbGVt\n" +
"ZW50PgogPC9lbGVtZW50Pgo8L2V4cG9ydD4K\n" +
"</ConfigModel>";
 private static final String CFG_PES_REC = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"PES_Aller\" etatID=\"PES_RecetteAller\" owner=\"Xemelios\" code=\"PES Recette - Tous champs\" libelle=\"PES Recette (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJQ\n" +
"RVMgUmVjZXR0ZSAtIFRvdXMgY2hhbXBzIiBsaWJlbGxlPSJQRVMgUmVjZXR0ZSAoY29uZmlnLiBw\n" +
"YXIgZOlmYXV0KSIgY29kZT0iIj4KIDxlbGVtZW50IGlkPSJCb3JkZXJlYXVSZWNldHRlIiBsaWJl\n" +
"bGxlPSJCb3JkZXJlYXV4Ij4KICA8Y2hhbXAgaWQ9ImU0bHIxIiBsaWJlbGxlPSJFeGVyY2ljZSIg\n" +
"ZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4K\n" +
"ICA8Y2hhbXAgaWQ9ImU0bHIyIiBsaWJlbGxlPSJUeXBlIiBlZGl0YWJsZT0iZmFsc2UiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0idHJ1ZSIvPgogIDxjaGFtcCBpZD0iZTRscjMiIGxp\n" +
"YmVsbGU9Ik51belybyIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9InRydWUiLz4KICA8Y2hhbXAgaWQ9ImU0bHI0IiBsaWJlbGxlPSJFbWlzc2lvbiIgZWRp\n" +
"dGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8\n" +
"Y2hhbXAgaWQ9ImU0bHI1IiBsaWJlbGxlPSJOYnJlIHRpdHJlcyIgZWRpdGFibGU9InRydWUiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImU0bHI2\n" +
"IiBsaWJlbGxlPSJNb250YW50IEhUIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iZTRscjciIGxpYmVsbGU9Ik1vbnRh\n" +
"bnQgVFRDIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJm\n" +
"YWxzZSIvPgogIDxlbGVtZW50IGlkPSJQaWVjZVJlY2V0dGUiIGxpYmVsbGU9IlRpdHJlcyI+CiAg\n" +
"IDxjaGFtcCBpZD0iZTVscjEiIGxpYmVsbGU9Ik51belybyBkZSB0aXRyZSIgZWRpdGFibGU9ImZh\n" +
"bHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICAgPGNoYW1wIGlk\n" +
"PSJlNWxyMiIgbGliZWxsZT0iVHlwZSBkZSB0aXRyZSIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rp\n" +
"b25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICAgPGNoYW1wIGlkPSJlNWxyMyIgbGli\n" +
"ZWxsZT0iTmF0dXJlIGRlIHRpdHJlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8Y2hhbXAgaWQ9ImU1bHI0IiBsaWJlbGxlPSJFeGVy\n" +
"Y2ljZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFs\n" +
"c2UiLz4KICAgPGNoYW1wIGlkPSJlNWxyNSIgbGliZWxsZT0iT2JqZXQgZHUgdGl0cmUiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxj\n" +
"aGFtcCBpZD0iZTVscjYiIGxpYmVsbGU9Ik1vbnRhbnQgSFQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxl\n" +
"Y3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgIDxjaGFtcCBpZD0iZTVscjci\n" +
"IGxpYmVsbGU9Ik1vbnRhbnQgVFRDIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogICA8ZWxlbWVudCBpZD0iTGlnbmVEZVBpZWNlUmVjZXR0\n" +
"ZSIgbGliZWxsZT0iTGlnbmVzIERlIFRpdHJlIj4KICAgIDxjaGFtcCBpZD0iZTZscjAiIGxpYmVs\n" +
"bGU9Ik51belybyBkZSBsaWduZSIgZWRpdGFibGU9ImZhbHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIg\n" +
"aWRlbnRpZmlhbnQ9InRydWUiLz4KICAgIDxjaGFtcCBpZD0iZTZscjEiIGxpYmVsbGU9IkV4ZXJj\n" +
"aWNlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxz\n" +
"ZSIvPgogICAgPGNoYW1wIGlkPSJlNmxyMiIgbGliZWxsZT0iT2JqZXQgZHUgdGl0cmUiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8\n" +
"Y2hhbXAgaWQ9ImU2bHIzIiBsaWJlbGxlPSJOdW3pcm8gZHUgdGl0cmUiIGVkaXRhYmxlPSJmYWxz\n" +
"ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJ0cnVlIi8+CiAgICA8Y2hhbXAgaWQ9\n" +
"ImU2bHI0IiBsaWJlbGxlPSJDb21wdGUgZGUgdGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rp\n" +
"b25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hhbXAgaWQ9ImU2bHI1IiBs\n" +
"aWJlbGxlPSJJbXB1dGF0aW9uIHBhciBuYXR1cmUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25u\n" +
"ZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgICA8Y2hhbXAgaWQ9ImU2bHI2IiBsaWJl\n" +
"bGxlPSJJbXB1dGF0aW9uIHBhciBmb25jdGlvbiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0iZTZscjciIGxpYmVs\n" +
"bGU9IkNvZGUgb3DpcmF0aW9uIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJlNmxyOCIgbGliZWxsZT0iTW9udGFu\n" +
"dCBIVCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFs\n" +
"c2UiLz4KICAgIDxjaGFtcCBpZD0iZTZscjkiIGxpYmVsbGU9Ik1vbnRhbnQgVFZBIiBlZGl0YWJs\n" +
"ZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNo\n" +
"YW1wIGlkPSJlNmxyMTAiIGxpYmVsbGU9IkxpZ25lIGRlIHRpdHJlIG1ham9yYWJsZSIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxj\n" +
"aGFtcCBpZD0iZTZscjExIiBsaWJlbGxlPSJNb250YW50IFRUQyIgZWRpdGFibGU9InRydWUiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0iZTZs\n" +
"cjEyIiBsaWJlbGxlPSJEYXRlIGRlIHBy6WzodmVtZW50IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0\n" +
"aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJlNmxyMTMi\n" +
"IGxpYmVsbGU9IkV4ZXJjaWNlIGRlIHJhdHRhY2hlbWVudCIgZWRpdGFibGU9InRydWUiIHNlbGVj\n" +
"dGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICAgIDxjaGFtcCBpZD0iZTZscjE0\n" +
"IiBsaWJlbGxlPSJOdW3pcm8gZGUgbWFyY2jpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogICAgPGNoYW1wIGlkPSJlNmxyMTUiIGxpYmVs\n" +
"bGU9Ik51belybyBkZSBy6WdpZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBp\n" +
"ZGVudGlmaWFudD0iZmFsc2UiLz48L2VsZW1lbnQ+CiAgPC9lbGVtZW50PgogPC9lbGVtZW50Pgo8\n" +
"L2V4cG9ydD4K\n" +
"</ConfigModel>";
 
 private static final String CFG_PES_PJ = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"PES_Aller\" etatID=\"PES_PJ\" owner=\"Xemelios\" code=\"PES PJ - Tous champs\" libelle=\"PES PJ (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJQ\n" +
"RVMgUEogLSBUb3VzIGNoYW1wcyIgbGliZWxsZT0iUEVTIFBKIChjb25maWcuIHBhciBk6WZhdXQp\n" +
"IiBjb2RlPSIiPgogPGVsZW1lbnQgaWQ9IlBKIiBsaWJlbGxlPSJQaehjZXMgSnVzdGlmaWNhdGl2\n" +
"ZXMiPgogIDxjaGFtcCBpZD0iZTdscjEiIGxpYmVsbGU9IlR5cGVQSiIgZWRpdGFibGU9InRydWUi\n" +
"IHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImU3\n" +
"bHIyIiBsaWJlbGxlPSJOb21QSiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBp\n" +
"ZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImU3bHIzIiBsaWJlbGxlPSJEZXNjcmlw\n" +
"dGlvbiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFs\n" +
"c2UiLz4KICA8Y2hhbXAgaWQ9ImU3bHI0IiBsaWJlbGxlPSJJZFVuaXF1ZSIgZWRpdGFibGU9ImZh\n" +
"bHNlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9InRydWUiLz4KICA8Y2hhbXAgaWQ9\n" +
"ImU3bHI1IiBsaWJlbGxlPSJTZXJ2ZXVySWQiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+PC9lbGVtZW50Pgo8L2V4cG9ydD4K\n" +
"</ConfigModel>";
 
 private static final String CFG_ERAR = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n" +
"<ConfigModel docID=\"erar\" etatID=\"LigneERAR\" owner=\"Xemelios\" code=\"ERAR - Tous champs\" libelle=\"ERAR (config. par dfaut)\">PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSI/Pgo8ZXhwb3J0IGlkPSJF\n" +
"UkFSIC0gVG91cyBjaGFtcHMiIGxpYmVsbGU9IkVSQVIgKGNvbmZpZy4gcGFyIGTpZmF1dCkiIGNv\n" +
"ZGU9IiI+CiA8ZWxlbWVudCBpZD0iTGlnbmVFUkFSIiBsaWJlbGxlPSJMaWduZSBFUkFSIj4KICA8\n" +
"Y2hhbXAgaWQ9IklkQ29sbCIgbGliZWxsZT0iSWQuIENvbGwuIiBlZGl0YWJsZT0idHJ1ZSIgc2Vs\n" +
"ZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iRmluSnVy\n" +
"IiBsaWJlbGxlPSJGaW5lc3MgSnVyLiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVl\n" +
"IiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkNvZENvbCIgbGliZWxsZT0iQ29k\n" +
"ZSBDb2xsLiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkNvZEJ1ZCIgbGliZWxsZT0iQ29kZSBCdWRnZXQiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJMaWJlbGxlQ29sQnVkIiBsaWJlbGxlPSJCdWRnZXQgQ29sbC4iIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlk\n" +
"PSJvcmRvIiBsaWJlbGxlPSJTdmNlIE9yZG9ubi4iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25u\n" +
"ZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJSZWZDb21wdGFUeXBl\n" +
"UmVmIiBsaWJlbGxlPSJS6WYuIENvbXB0YS4gVHlwZSBy6WYuIiBlZGl0YWJsZT0idHJ1ZSIgc2Vs\n" +
"ZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iUmVmQ29t\n" +
"cHRhSWRCb3JkIiBsaWJlbGxlPSJSZWYuIENvbXB0YS4gQm9yZC4iIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJSZWZD\n" +
"b21wdGFJZFBpZWNlIiBsaWJlbGxlPSJS6WYuIENvbXB0YS4gUGnoY2UiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJS\n" +
"ZWZDb21wdGFFeGVyUmF0dGFjaCIgbGliZWxsZT0iUulmLiBDb21wdGEuIEV4ZXIiIGVkaXRhYmxl\n" +
"PSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1w\n" +
"IGlkPSJSZWZDb21wdGFJZExpZ25lIiBsaWJlbGxlPSJS6WYuIENvbXB0YS4gTGlnbmUiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJSZWZDb21wdGFOdW1GYWN0IiBsaWJlbGxlPSJS6WYuIENvbXB0YS4gRmFjdHVyZSIg\n" +
"ZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4K\n" +
"ICA8Y2hhbXAgaWQ9IlJlZkNvbXB0YUNvZGVQZXJpb2RlIiBsaWJlbGxlPSJS6WYuIENvbXB0YS4g\n" +
"Q29kZSBw6XJpb2RlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iUmVmQ29tcHRhQ29kUHJvZCIgbGliZWxsZT0iUulm\n" +
"LiBDb21wdGEuIENvZGUgUHJvZC4iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIg\n" +
"aWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJSZWZDb21wdGFMaWJQcm9kIiBsaWJl\n" +
"bGxlPSJS6WYuIENvbXB0YS4gUHJvZHVpdCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IlJlZkNvbXB0YURhdGVQY2Ui\n" +
"IGxpYmVsbGU9IlLpZi4gQ29tcHRhLiBEYXRlIFBp6GNlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0\n" +
"aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iRGViSWRUaWVy\n" +
"cyIgbGliZWxsZT0iROliLiBJZCBUaWVycyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRlYkRhdGVNYWxhZGUiIGxp\n" +
"YmVsbGU9IkTpYi4gRGF0ZSBtYWxhZGUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJUeXBUaWVycyIgbGliZWxs\n" +
"ZT0iROliLiBUeXBlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iRGViVHlwVGllcnNDb2RlIiBsaWJlbGxlPSJE6WIu\n" +
"IFR5cGUgVGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlh\n" +
"bnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJOYXRJZFRpZXJzIiBsaWJlbGxlPSJE6WIuIE5h\n" +
"dC4gSWQgVGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlh\n" +
"bnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJEdGVJZFRpZXJzIiBsaWJlbGxlPSJE6WIuIERh\n" +
"dGUgSWQgVGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlh\n" +
"bnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJSZWZUaWVycyIgbGliZWxsZT0iROliLiBS6WYu\n" +
"IFRpZXJzIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJm\n" +
"YWxzZSIvPgogIDxjaGFtcCBpZD0iRGViQ2F0VGllcnMiIGxpYmVsbGU9IkTpYi4gQ2F0LiBUaWVy\n" +
"cyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2Ui\n" +
"Lz4KICA8Y2hhbXAgaWQ9IkRlYk5hdEp1ciIgbGliZWxsZT0iROliLiBOYXQuIEp1ci4iIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJEZWJDaXZpbGl0ZSIgbGliZWxsZT0iROliLiBDaXZpbGl06SIgZWRpdGFibGU9InRy\n" +
"dWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9\n" +
"IkRlYk5vbSIgbGliZWxsZT0iROliLiBOb20iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJDb21wbE5vbSIgbGli\n" +
"ZWxsZT0iROliLiBDb21wbC4gTm9tIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iRGViUHJlbm9tIiBsaWJlbGxlPSJE\n" +
"6WIuIFBy6W5vbSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFu\n" +
"dD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRlYlR5cEFkciIgbGliZWxsZT0iROliLiBUeXBlIEFk\n" +
"ciIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2Ui\n" +
"Lz4KICA8Y2hhbXAgaWQ9IkRlYkFkcjEiIGxpYmVsbGU9IkTpYi4gQWRyMSIgZWRpdGFibGU9InRy\n" +
"dWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9\n" +
"IkRlYkFkcjIiIGxpYmVsbGU9IkTpYi4gQWRyMiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5l\n" +
"PSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRlYkFkcjMiIGxpYmVs\n" +
"bGU9IkTpYi4gQWRyMyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlm\n" +
"aWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRlYkNQIiBsaWJlbGxlPSJE6WIuIENQIiBlZGl0\n" +
"YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxj\n" +
"aGFtcCBpZD0iRGViVmlsbGUiIGxpYmVsbGU9IkTpYi4gVmlsbGUiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJO\n" +
"UEFJIiBsaWJlbGxlPSJE6WIuIE5QQUkiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEZWJDb2RSZXMiIGxpYmVsbGU9\n" +
"IkTpYi4gQ29kZSBS6XMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJE6WJDb2RQYXlzIiBsaWJlbGxlPSJE6WIuIENv\n" +
"ZGUgUGF5cyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRlYlJlZkFsbG9jYXRhaXJlIiBsaWJlbGxlPSJE6WIuIFLp\n" +
"Zi4gQWxsb2NhdGFpcmUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRp\n" +
"ZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJBc3NJZFRpZXJzIiBsaWJlbGxlPSJBc3MuIElk\n" +
"IFRpZXJzIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJm\n" +
"YWxzZSIvPgogIDxjaGFtcCBpZD0iQXNzRGF0ZU1hbGFkZSIgbGliZWxsZT0iQXNzLiBEYXRlIG1h\n" +
"bGFkZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFs\n" +
"c2UiLz4KICA8Y2hhbXAgaWQ9IkFzc1R5cFRpZXJzIiBsaWJlbGxlPSJBc3MuIFR5cGUiIGVkaXRh\n" +
"YmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNo\n" +
"YW1wIGlkPSJBc3NUeXBUaWVyc0NvZGUiIGxpYmVsbGU9IkFzcy4gVHlwZSBUaWVycyIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hh\n" +
"bXAgaWQ9IkFzc05hdElkVGllcnMiIGxpYmVsbGU9IkFzcy4gTmF0LiBJZCBUaWVycyIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hh\n" +
"bXAgaWQ9IkFzc0R0ZUlkVGllcnMiIGxpYmVsbGU9IkFzcy4gRGF0ZSBJZCBUaWVycyIgZWRpdGFi\n" +
"bGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hh\n" +
"bXAgaWQ9IkFzc1JlZlRpZXJzIiBsaWJlbGxlPSJBc3MuIFLpZi4gVGllcnMiIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlk\n" +
"PSJBc3NDYXRUaWVycyIgbGliZWxsZT0iQXNzLiBDYXQuIFRpZXJzIiBlZGl0YWJsZT0idHJ1ZSIg\n" +
"c2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iQXNz\n" +
"TmF0SnVyIiBsaWJlbGxlPSJBc3MuIE5hdC4gSnVyLiIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkFzc0NpdmlsaXRl\n" +
"IiBsaWJlbGxlPSJBc3MuIENpdmlsaXTpIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRy\n" +
"dWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iQXNzTm9tIiBsaWJlbGxlPSJB\n" +
"c3MuIE5vbSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkFzc0NvbXBsTm9tIiBsaWJlbGxlPSJBc3MuIENvbXBsLiBO\n" +
"b20iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNl\n" +
"Ii8+CiAgPGNoYW1wIGlkPSJBc3NQcmVub20iIGxpYmVsbGU9IkFzcy4gUHLpbm9tIiBlZGl0YWJs\n" +
"ZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFt\n" +
"cCBpZD0iTWFsSWRUaWVycyIgbGliZWxsZT0iTWFsLiBJZCBUaWVycyIgZWRpdGFibGU9InRydWUi\n" +
"IHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9Ik1h\n" +
"bERhdGVNYWxhZGUiIGxpYmVsbGU9Ik1hbC4gRGF0ZSBtYWxhZGUiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNYWxU\n" +
"eXBUaWVycyIgbGliZWxsZT0iTWFsLiBUeXBlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9\n" +
"InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iTWFsVHlwVGllcnNDb2Rl\n" +
"IiBsaWJlbGxlPSJNYWwuIFR5cGUgVGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNYWxOYXRJZFRpZXJzIiBs\n" +
"aWJlbGxlPSJNYWwuIE5hdC4gSWQgVGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNYWxEdGVJZFRpZXJzIiBs\n" +
"aWJlbGxlPSJNYWwuIERhdGUgSWQgVGllcnMiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNYWxSZWZUaWVycyIgbGli\n" +
"ZWxsZT0iTWFsLiBS6WYuIFRpZXJzIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iTWFsQ2F0VGllcnMiIGxpYmVsbGU9\n" +
"Ik1hbC4gQ2F0LiBUaWVycyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVu\n" +
"dGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9Ik1hbE5hdEp1ciIgbGliZWxsZT0iTWFsLiBO\n" +
"YXQuIEp1ci4iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9\n" +
"ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNYWxDaXZpbGl0ZSIgbGliZWxsZT0iTWFsLiBDaXZpbGl0\n" +
"6SIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2Ui\n" +
"Lz4KICA8Y2hhbXAgaWQ9Ik1hbE5vbSIgbGliZWxsZT0iTWFsLiBOb20iIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJN\n" +
"YWxDb21wbE5vbSIgbGliZWxsZT0iTWFsLiBDb21wbC4gTm9tIiBlZGl0YWJsZT0idHJ1ZSIgc2Vs\n" +
"ZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iTWFsUHJl\n" +
"bm9tIiBsaWJlbGxlPSJNYWwuIFBy6W5vbSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0\n" +
"cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9Ik1hbERhdGVFbnRyZWUiIGxp\n" +
"YmVsbGU9Ik1hbC4gRGF0ZSBlbnRy6WUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNYWxEYXRlU29ydGllIiBsaWJl\n" +
"bGxlPSJNYWwuIERhdGUgc29ydGllIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUi\n" +
"IGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iTWFsTnVtRW50cmVlIiBsaWJlbGxl\n" +
"PSJNYWwuIE51bSBlbnRy6WUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRl\n" +
"bnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJNdFByaW5jIiBsaWJlbGxlPSJNdCBQcmlu\n" +
"Y2lwYWwiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZh\n" +
"bHNlIi8+CiAgPGNoYW1wIGlkPSJNdEZyYWlzIiBsaWJlbGxlPSJNdCBGcmFpcyIgZWRpdGFibGU9\n" +
"InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAg\n" +
"aWQ9IlJhclByaW5jIiBsaWJlbGxlPSJSQVIgUHJpbmNpcGFsIiBlZGl0YWJsZT0idHJ1ZSIgc2Vs\n" +
"ZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iUmFyRnJh\n" +
"aXMiIGxpYmVsbGU9IlJhciBGcmFpcyIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVl\n" +
"IiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRhdGVOViIgbGliZWxsZT0iRGF0\n" +
"ZSBhZG0uIE5WIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50\n" +
"PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iTXROViIgbGliZWxsZT0iTXQgTlYiIGVkaXRhYmxlPSJ0\n" +
"cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlk\n" +
"PSJEYXRlTWFqb3JhdGlvbiIgbGliZWxsZT0iRGF0ZSBNYWpvLiIgZWRpdGFibGU9InRydWUiIHNl\n" +
"bGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkRhdGVQ\n" +
"cmVzY3JpcHRpb24iIGxpYmVsbGU9IkRhdGUgcHJlc2NyaXB0aW9uIiBlZGl0YWJsZT0idHJ1ZSIg\n" +
"c2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iZXRh\n" +
"YkdlbyIgbGliZWxsZT0iRXRhYmwuIGfpby4iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0i\n" +
"dHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJDb2RQcm9kTG9jYWwiIGxp\n" +
"YmVsbGU9IkNvZGUgcHJvZC4gbG9jYWwiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1\n" +
"ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEYXRlRGViRmFjdCIgbGliZWxs\n" +
"ZT0iRGF0ZSBk6WIuIEZhY3QuIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlk\n" +
"ZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iRGF0ZUZpbkZhY3QiIGxpYmVsbGU9IkRh\n" +
"dGUgZmluIEZhY3QuIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0ibGliRW1wIiBsaWJlbGxlPSJFbXAuIExpYiBFbXBl\n" +
"Y2hlbWVudCIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBpZGVudGlmaWFudD0i\n" +
"ZmFsc2UiLz4KICA8Y2hhbXAgaWQ9ImNvZEVtcCIgbGliZWxsZT0iRW1wLiBDb2RlIEVtcGVjaGVt\n" +
"ZW50IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxz\n" +
"ZSIvPgogIDxjaGFtcCBpZD0iZGF0ZUFubnVhdGlvbiIgbGliZWxsZT0iRXRwLiBEYXRlIEFubnVs\n" +
"YXRpb24iIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZh\n" +
"bHNlIi8+CiAgPGNoYW1wIGlkPSJNdEZyYWlzRXRhcGUiIGxpYmVsbGU9IkV0cC4gTXQgRnJhaXMi\n" +
"IGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+\n" +
"CiAgPGNoYW1wIGlkPSJDb2RlQWN0dSIgbGliZWxsZT0iRXRwLiBDb2RlIEFjdHUuIiBlZGl0YWJs\n" +
"ZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFt\n" +
"cCBpZD0iRGF0ZUV0YXBlIiBsaWJlbGxlPSJFdHAuIERhdGUgRXRhcGUiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJE\n" +
"YXRlUmVtaXNlQWN0ZSIgbGliZWxsZT0iRXRwLiBEYXRlIFJlbWlzZSBBY3RlIiBlZGl0YWJsZT0i\n" +
"dHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBp\n" +
"ZD0iTXRBY3RlUG91cnN1aXRlIiBsaWJlbGxlPSJFdHAuIE10IEFjdGUgUG91cnN1aXRlIiBlZGl0\n" +
"YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxj\n" +
"aGFtcCBpZD0iUmVmQWN0ZSIgbGliZWxsZT0iRXRwLiBSZWYuIEFjdGUiIGVkaXRhYmxlPSJ0cnVl\n" +
"IiBzZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJO\n" +
"YXRFdGFwZSIgbGliZWxsZT0iRXRwLiBOYXQuIEV0YXBlIiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0\n" +
"aW9ubmU9InRydWUiIGlkZW50aWZpYW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iRGF0ZUF1dG9t\n" +
"YXRlIiBsaWJlbGxlPSJFdHAuIERhdGUgQXV0b21hdGUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rp\n" +
"b25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEYXRlRGVtYW5k\n" +
"ZUFjdGUiIGxpYmVsbGU9IkV0cC4gRGF0ZSBEZW1hbmRlIEFjdGUiIGVkaXRhYmxlPSJ0cnVlIiBz\n" +
"ZWxlY3Rpb25uZT0idHJ1ZSIgaWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJDb2Rl\n" +
"RXRhcGUiIGxpYmVsbGU9IkV0cC4gQ29kZSBFdGFwZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlv\n" +
"bm5lPSJ0cnVlIiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9Ik10RXRhcGUiIGxp\n" +
"YmVsbGU9IkV0cC4gTXQgRXRhcGUiIGVkaXRhYmxlPSJ0cnVlIiBzZWxlY3Rpb25uZT0idHJ1ZSIg\n" +
"aWRlbnRpZmlhbnQ9ImZhbHNlIi8+CiAgPGNoYW1wIGlkPSJEYXRlRW52b2lBY3RlIiBsaWJlbGxl\n" +
"PSJFdHAuIERhdGUgRW52b2kgQWN0ZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVl\n" +
"IiBpZGVudGlmaWFudD0iZmFsc2UiLz4KICA8Y2hhbXAgaWQ9IkxpYkFjdHUiIGxpYmVsbGU9IkV0\n" +
"cC4gTGliLiBBY3R1IiBlZGl0YWJsZT0idHJ1ZSIgc2VsZWN0aW9ubmU9InRydWUiIGlkZW50aWZp\n" +
"YW50PSJmYWxzZSIvPgogIDxjaGFtcCBpZD0iTnVtQWN0ZVBvdXJzdWl0ZSIgbGliZWxsZT0iRXRw\n" +
"Lk51bSBBY3RlIFBvdXJzdWl0ZSIgZWRpdGFibGU9InRydWUiIHNlbGVjdGlvbm5lPSJ0cnVlIiBp\n" +
"ZGVudGlmaWFudD0iZmFsc2UiLz48L2VsZW1lbnQ+CjwvZXhwb3J0Pgo=\n" +
"</ConfigModel>";

    
    private static final String[] EXPORT_CONFIGS = {
        CFG_PAYE_BULLETIN, CFG_PAYE_REPART_NAT,
        CFG_VERSEMENT_VERS, CFG_VERSEMENT_REPART,
        CFG_FACTURE_DEP, CFG_CARTE_ACHAT, CFG_FACTURE_REC, CFG_QUITTANCEMENT,
        CFG_PES_DEP, CFG_PES_REC, CFG_PES_PJ,
        CFG_ERAR
    };
    
    public Core33114() {
        super();
    }

    @Override
    public void run() throws Exception {
        XemeliosUser user = new LocalUser();
        try {
            ConfigParser parser = new  ConfigParser();
            DataImpl impl = DataLayerManager.getImplementation();
            for(String s: EXPORT_CONFIGS) {
                parser.parse(new ByteArrayInputStream(s.getBytes("ISO-8859-1")));
                ConfigModel cm = (ConfigModel)parser.getMarshallable();
                
                Vector<ConfigModel> existing = impl.getListeConfigsExport(cm.getDocID(), cm.getEtatID(),user);
                boolean exists = false;
                for(ConfigModel ecm:existing) {
                    if(ecm.getCode().equals(cm.getCode())) {
                        exists = true;
                        break;
                    }
                }
                if(!exists) {
                    impl.insertConfigExport(cm,user);
                }
            }
        } catch(Throwable t) {
            t.printStackTrace();
        }
        setPreviousConfigurator(new Core3316());
    }

    /**
     * @TODO : AUTHORISATIONS A GERER CORRECTEMENT
     */
    public static class LocalUser implements XemeliosUser {

        public String getId() {
            return "local";
        }

        public String getDisplayName() {
            return getId();
        }

        public boolean hasRole(String arg0) {
            return true;
        }

        public boolean hasDocument(String arg0) {
            return true;
        }

        public boolean hasCollectivite(String arg0, DocumentModel dm) {
            return true;
        }

    }

}
