/*
 * Copyright
 *   2007 axYus - www.axyus.com
 *   2007 C.Marchand - christophe.marchand@axyus.com
 *
 * This file is part of XEMELIOS.
 *
 * XEMELIOS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * XEMELIOS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with XEMELIOS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package fr.gouv.finances.cp.xemelios.updater.script.config;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

import fr.gouv.finances.cp.utils.xml.marshal.InvalidXmlDefinition;
import fr.gouv.finances.cp.utils.xml.marshal.XmlAttributes;
import fr.gouv.finances.cp.utils.xml.marshal.XmlMarshallable;
import fr.gouv.finances.cp.utils.xml.marshal.XmlOutputter;
import javax.xml.namespace.QName;

public class ComponentModel implements XmlMarshallable {
	public static final transient String TAG = "component";
        public static final transient QName QN = new QName(TAG);
	
	private String id, version, description;

	public ComponentModel(QName tagName) {
		super();
	}
	public ComponentModel(String id, String version, String description) {
		this(QN);
		this.id=id;
		this.version=version;
		this.description=description;
	}

	public void addCharacterData(String cData) throws SAXException { }

	public void addChild(XmlMarshallable child, QName tagName) throws SAXException { }

	public XmlMarshallable getAttributes(XmlAttributes attributes) throws SAXException {
		id = attributes.getValue("id");
		version = attributes.getValue("version");
		description = attributes.getValue("description");
		return this;
	}

	public void marshall(XmlOutputter output) {
		output.startTag(TAG);
		output.addAttribute("id",id);
		output.addAttribute("version",version);
		output.addAttribute("description",description);
		output.endTag(TAG);
	}

	public void validate() throws InvalidXmlDefinition { }

	@Override
	public ComponentModel clone() {
		return this;
	}

	public String getDescription() {
		return description;
	}

	public String getId() {
		return id;
	}

	public String getVersion() {
		return version;
	}
	@Override
	public boolean equals(Object o) {
		if(o instanceof ComponentModel) {
			ComponentModel cm = (ComponentModel)o;
			return cm.getId().equals(getId());
		}
		return false;
	}

    public XmlMarshallable getChildToModify(String uri, String localName, String qName, Attributes atts) {
        return null;
    }

    public QName getQName() {
        return QN;
    }
}
